==> spicecode-2.1.3.tar.gz: spicecode-2.1.3/cli/translations/fremen.py <==
messages = {
    # keys for the hello command
    "welcome": "🌶️ Salam, wanderer, and welcome to the sietch of [bold red]SpiceCode[/]! 🌶️",
    "description": "🔥 The [yellow]Fedaykin CLI[/] that ignites your code with spice, as fierce as Arrakis' dunes 🥵",
    # error messages
    "error": "خطأ:",
    # keys for the analyze command output
    "analyzing_file": "Deciphering the file's sand-script",
    "line_count": "The file spans {count} dunes",
    "function_count": "The file holds {count} sacred routines",
    "comment_line_count": "The file whispers {count} lines of hidden lore",
    "inline_comment_count": "The file contains {count} passages of dual meaning",
    # keys for analyze command checkbox menu
    "select_stats": "Choose the omens to unveil:",
    "line_count_option": "Dune Count",
    "function_count_option": "Sacred Routines", 
    "comment_line_count_option": "Whispered Lore",
    "inline_comment_count_option": "Passages of Dual Meaning",
    "no_stats_selected": "No omens were heeded. The analysis fades into the sands.",
    "confirm_and_analyze": "Seal your fate and analyze",
    "checkbox_hint": "(Use space to mark, enter to proceed)",
    "indentation_level_option": "Sand Pattern Reading",
    "indentation_type": "Kind of Sand Grain",
    "indentation_size": "Size of the Sand Grain",
    "external_dependencies_count_option": "Grains of Sand Beyound Dune",
    "methods_count_option": "Kinds of Rituals",
    "private_methods_count_option": "Hidden Rituals",
    "public_methods_count_option": "Open Rituals",
    "comment_ratio_option": "Whisper to Sand Ratio",
}

==> spicecode-2.2.0.tar.gz: spicecode-2.2.0/cli/translations/fremen.py <==
messages = {
    # keys for the hello command
    "welcome": "🌶️ Salam, wanderer, and welcome to the sietch of [bold red]SpiceCode[/]! 🌶️",
    "description": "🔥 The [yellow]Fedaykin CLI[/] that ignites your code with spice, as fierce as Arrakis' dunes 🥵",
    # error messages
    "error": "خطأ:",
    # keys for the analyze command output
    "analyzing_file": "Deciphering the file's sand-script",
    "line_count": "The file spans {count} dunes",
    "function_count": "The file holds {count} sacred routines",
    "comment_line_count": "The file whispers {count} lines of hidden lore",
    "inline_comment_count": "The file contains {count} passages of dual meaning",
    # keys for analyze command checkbox menu
    "select_stats": "Choose the omens to unveil:",
    "line_count_option": "Dune Count",
    "function_count_option": "Sacred Routines", 
    "comment_line_count_option": "Whispered Lore",
    "inline_comment_count_option": "Passages of Dual Meaning",
    "no_stats_selected": "No omens were heeded. The analysis fades into the sands.",
    "confirm_and_analyze": "Seal your fate and analyze",
    "checkbox_hint": "(Use space to mark, enter to proceed)",
    "indentation_level_option": "Sand Pattern Reading",
    "indentation_type": "Kind of Sand Grain",
    "indentation_size": "Size of the Sand Grain",
    "external_dependencies_count_option": "Grains of Sand Beyond Dune",
    "methods_count_option": "Kinds of Rituals",
    "private_methods_count_option": "Hidden Rituals",
    "public_methods_count_option": "Open Rituals",
    "comment_ratio_option": "Whisper to Sand Ratio",
}
